from typing import Any

import anyio
import dill

from .datastructures import Task


class Client:
    def __init__(self, port: int = 1956):
        self.port = port

    def serialize(self, task: Task) -> bytes:
        """Convert python function and parameters"""
        return dill.dumps(task)

    def deserialize(self, result: bytes) -> Any:
        return dill.loads(result)

    async def ping(self):
        """Send name to TCP server."""
        async with await anyio.connect_tcp("localhost", self.port) as client:
            await client.send(b"PING")
            return await client.receive()

    async def send_task(self, task: Task):
        """Send task to TCP server."""
        bt = self.serialize(task)
        async with await anyio.connect_tcp("localhost", self.port) as client:
            await client.send(bt)



import sys

sys.path.append("/opt/extensions")
import anyio
import typer
from server import Server

from lambchop.client import Client

app = typer.Typer()


@app.command()
def pinger():
    c = Client()
    out = anyio.run(c.ping)
    print(out)


@app.command()
def serve(port: int = typer.Option(1956, help="Port to listen on.")):
    s = Server(port=port)
    anyio.run(s.serve)


if __name__ == "__main__":
    app()
